==> vmaid-1.8.21.tar.gz: vmaid-1.8.21/src/jump.h <==
/*
    Video maid
    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __JUMP_H__
#define __JUMP_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef struct JumpDialog_Tag
{
  gint frame, max;
  guint32 rate, scale;
} JumpDialog;


/******************************************************************************
*                                                                             *
* ja:ジャンプダイアログ関数群                                                 *
*                                                                             *
******************************************************************************/
/*  ja:ジャンプダイアログ表示
    jmp,ジャンプ構造体
    RET.TRUE:OK,FALSE:Cancel                                                */
gboolean
jump_dialog (JumpDialog *jmp);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif

==> vmaid-1.9.2.tar.gz: vmaid-1.9.2/src/jump.h <==
/*
    Video maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __JUMP_H__
#define __JUMP_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef struct _JumpDialog
{
  gint frame, max;
  guint32 rate, scale;
} JumpDialog;


/******************************************************************************
*                                                                             *
* ja:ジャンプダイアログ関数群                                                 *
*                                                                             *
******************************************************************************/
/*  ja:ジャンプダイアログ表示
    jmp,ジャンプ構造体
    RET.TRUE:OK,FALSE:Cancel                                                */
gboolean
jump_dialog (JumpDialog *jmp);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __JUMP_H__ */
